@@ -24,7 +24,7 @@ class RepoRefCache(object):
     def _run_cmd(self, cmd):
         try:
             return subprocess.check_output(cmd, stderr=subprocess.STDOUT)
-        except subprocess.CalledProcessError:
+        except (subprocess.CalledProcessError, FileNotFoundError):
             return None
 
     def _strip_ref(self, ref):
@@ -94,12 +94,18 @@ class CDNStaticURLNode(Node):
             parts.fragment))
 
 
-@register.tag('cdnstatic')
+class CDNTagNode(Node):
+
+    def render(self, *args, **kwargs):
+        return refcache.get_ref()
+
+
+@register.tag(name='cdnstatic')
 def do_cdnstatic(parser, token):
     url = do_static(parser, token)
     return CDNStaticURLNode(url)
 
 
-@register.tag('cdntag')
+@register.tag(name='cdntag')
 def do_cdntag(parser, token):
-    return refcache.get_ref()
+    return CDNTagNode()
